@@ -1,4 +1,5 @@
 from quickbase_client.client.api import QuickBaseApiClient
+from quickbase_client.client.pager import ResponsePager
 from quickbase_client.client.table_client import QuickBaseQuery
 from quickbase_client.client.table_client import QuickBaseTableClient
 from quickbase_client.orm.app import QuickBaseApp
@@ -10,6 +11,7 @@ from quickbase_client.orm.table import QuickBaseTable
 
 __all__ = [
     'QuickBaseApp',
+    'ResponsePager',
     'QuickBaseField',
     'QuickBaseFieldType',
     'QuickBaseReport',
